@@ -5,8 +5,8 @@ use strict;
 use Devscripts::Compression qw'compression_is_supported
   compression_guess_from_file';
 use Devscripts::Uscan::Output;
+use Dpkg::Path qw(find_command);
 use Exporter 'import';
-use File::Which;
 use Moo;
 
 use constant default_compression => 'xz';
@@ -172,7 +172,7 @@ use constant rules => [
                   . " to be able to repack "
                   . $self->upstream_comp
                   . " upstream archives.\n")
-              unless (which $prog);
+              unless (find_command($prog));
         } else {
             if ($self->upstream =~ /\.tar$/ and $mime eq 'tar') {
                 $self->upstream_type('tar');
