@@ -283,7 +283,9 @@ sub download ($$$$$$$$) {
                         exec       => [@cmd],
                         to_string  => \$tmp,
                         wait_child => 1,
-                        nocheck    => 1,
+                        no_check   => 1,
+                      # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+                        nocheck => 1,
                     );
                     chomp $tmp;
                     my @sm_active = (split '\n', $tmp);
