@@ -403,7 +403,12 @@ while ($control = shift) {
                     version   => $ctrl->{Version} });
         }
     }
-    wait_child($pid, nocheck => 1) if defined $pid;
+    wait_child(
+        $pid,
+        no_check => 1,
+        # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+        nocheck => 1,
+    ) if defined $pid;
     # Only use the newest version.  We'll only have this if processing showsrc
     # output or a dsc file.
     if (@versions) {
@@ -453,8 +458,10 @@ if ($opt_install) {
                   ['dpkg-query', '-W', '-f', '${db:Status-Status}', $pkg],
                 to_string     => \$status,
                 error_to_file => '/dev/null',
-                nocheck       => 1,
-                wait_child    => 1
+                wait_child    => 1,
+                no_check      => 1,
+                # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+                nocheck => 1,
             );
             if ($status ne 'installed' || ($? >> 8)) {
                 # Restore system to previous state, since $install_tool wasn't
