@@ -18,12 +18,15 @@ salsa - tool to manipulate salsa projects, repositories and group members
   salsa fork salsa fork --group js-team user/node-foo
   salsa last_ci_status js-team/nodejs
   salsa pipelines js-team/nodejs
-  salsa mr debian/foo debian/master
+  salsa mr debian/foo debian/latest
   salsa push_repo . --group js-team --kgb --irc devscripts --tagpending
   salsa update_projects node-mongodb --group js-team --disable-kgb --desc \
         --desc-pattern "Package %p"
   salsa update_safe --all --desc --desc-pattern "Debian package %p" \
         --group js-team
+  salsa update_watch5 debian/devscripts
+  salsa update_watch5 --group js-team --all
+
 
 =head1 DESCRIPTION
 
@@ -159,6 +162,7 @@ exists, update local repository.
   salsa --user yadd checkout devscripts
   salsa --group js-team checkout node-mongodb
   salsa checkout js-team/node-mongodb
+  salsa checkout https://salsa.debian.org/debian/devscripts.git
 
 You can clone more than one repository or all repositories of a group or a
 user:
@@ -280,11 +284,11 @@ I<(branch "master")>. You just have to launch this in source directory:
 
 Another example:
 
-  salsa merge_request --mr-dst-project debian/foo --mr-dst-branch debian/master
+  salsa merge_request --mr-dst-project debian/foo --mr-dst-branch debian/latest
 
 Or simply:
 
-  salsa merge_request debian/foo debian/master
+  salsa merge_request debian/foo debian/latest
 
 Note that unless destination project has been set using command line,
 B<salsa merge_request> will search it in the following order:
@@ -421,6 +425,19 @@ Launch B<check_projects> and ask before launching B<update_projects> (unless B<-
   salsa --group js-team --rename-head update_safe test1 test2 test3
   salsa update_safe js-team/node-mongodb --kgb --irc debian-js
 
+=item B<update_watch5>
+
+Update C<debian/watch> file for each given project to L<version 5|debian-watch(5)>.
+
+Options B<--all> and B<--debian-branch> are usable here.
+
+=item B<path>
+
+Little subcommand to get salsa path from a local git repo:
+
+  salsa path
+  salsa path ./directory
+
 =back
 
 =head2 Other
@@ -924,7 +941,7 @@ C<.devscripts> value: B<SALSA_SOURCE_BRANCH>
 
 =item B<--dest-branch>
 
-Default: "debian/master".
+Default: "debian/latest".
 
 C<.devscripts> value: B<SALSA_DEST_BRANCH>
 
@@ -936,6 +953,11 @@ Enable, ignore or disable "tagpending" webhook.
 
 C<.devscripts> value: B<SALSA_TAGPENDING> (yes/ignore/no, default: ignore)
 
+=item B<--debian-branch>
+
+Set the branch to update for B<update_watch5> command. Default to project's
+default branch.
+
 =back
 
 =head2 Pipeline schedules
@@ -977,6 +999,16 @@ Delete B<--schedule-desc> pipeline schedule.
 
 =back
 
+=head2 CI status options
+
+=over
+
+=item B<--retry-failed-pipelines>
+
+Ask to GitLab to retry pipelines that have failed.
+
+=back
+
 =head2 Merge requests options
 
 =over
